# GroupBy


## Enum

* `AUTOMATION` (value: `'automation'`)

* `STATUS` (value: `'status'`)

* `LAST_STATUS` (value: `'last_status'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


